@@ -116,7 +116,7 @@ function configure_nova_docker {
 # configure_solum() - Set config files, create data dirs, etc
 function configure_solum() {
 
-    configure_nova_docker
+    # configure_nova_docker
 
     if [[ ! -d $SOLUM_CONF_DIR ]]; then
         sudo mkdir -p $SOLUM_CONF_DIR
@@ -163,9 +163,9 @@ function configure_solum() {
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_tenant_name service
 
     # configure the api servers to listen on
-    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE api host $SOLUM_SERVICE_HOST
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE api host $(ipv6_unquote $SOLUM_SERVICE_HOST)
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE api port $SOLUM_SERVICE_PORT
-    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE builder host $SOLUM_SERVICE_HOST
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE builder host $(ipv6_unquote $SOLUM_SERVICE_HOST)
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE builder port $SOLUM_BUILDER_SERVICE_PORT
 
     # configure assembly handler to create appropriate image format
@@ -349,7 +349,7 @@ function start_solum() {
         restart_apache_server
         tail_log solum-api /var/log/$APACHE_NAME/solum-api.log
     elif [ "$SOLUM_USE_UWSGI" == "True" ]; then
-        run_process solum-api "$SOLUM_BIN_DIR/uwsgi --ini $SOLUM_UWSGI_CONF"
+        run_process solum-api "$(which uwsgi) --ini $SOLUM_UWSGI_CONF"
     else
         run_process solum-api "$SOLUM_BIN_DIR/solum-api --config-file $SOLUM_CONF_DIR/$SOLUM_CONF_FILE"
     fi
