@@ -14,13 +14,12 @@
 
 import string
 
-import six
 import wsme
 from wsme import types as wtypes
 
 from solum.api.controllers.v1.datamodel import types as api_types
+from solum.i18n import _
 from solum import objects
-from solum.openstack.common.gettextutils import _
 
 TAGS = (TYPE, COMPILER_VERSION, RUNTIME_VERSION, IMPLEMENTATION,
         BUILD_TOOL, OS_PLATFORM, ATTRIBUTE, DESCRIPTION) = (
@@ -148,7 +147,7 @@ class LanguagePack(api_types.Base):
         wtypes.DictType(wtypes.text,
                         api_types.MultiType(
                             wtypes.text,
-                            six.integer_types,
+                            int,
                             bool,
                             float)))
 
