@@ -65,11 +65,12 @@ class Service(object):
 
     def __init__(self, topic, server, handlers):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
-        transport = messaging.get_notification_transport(cfg.CONF)
+        transport = messaging.get_rpc_transport(cfg.CONF)
         # TODO(asalkeld) add support for version='x.y'
         target = messaging.Target(topic=topic, server=server)
         access_policy = dispatcher.DefaultRPCAccessPolicy
         self._server = messaging.get_rpc_server(transport, target, handlers,
+                                                executor='threading',
                                                 serializer=serializer,
                                                 access_policy=access_policy)
 
@@ -83,7 +84,7 @@ class API(object):
     def __init__(self, transport=None, context=None, topic=None):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
         if transport is None:
-            transport = messaging.get_notification_transport(cfg.CONF)
+            transport = messaging.get_rpc_transport(cfg.CONF)
         self._context = context
         if topic is None:
             topic = ''
