@@ -12,7 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
+from oslo_config import cfg
 
 from solum.api.handlers import language_pack_handler
 from solum.common import exception as exc
@@ -49,14 +51,34 @@ class TestLanguagePackHandler(base.BaseTestCase):
         data = {'name': 'new app',
                 'source_uri': 'git@github.com/foo/foo.git'}
         fi = fakes.FakeImage()
+        cfg.CONF.set_override('max_languagepack_limit', '10',
+                              group='api')
+        mock_img.get_num_of_lps.return_value = 1
+
         mock_img.get_lp_by_name_or_uuid.side_effect = exc.ResourceNotFound()
         mock_img.return_value = fi
         handler = language_pack_handler.LanguagePackHandler(self.ctx)
-        res = handler.create(data, lp_metadata=None)
-        mock_lp_build.assert_called_once_with(res)
+        res = handler.create(data, lp_metadata=None, lp_params=None)
+        mock_lp_build.assert_called_once_with(res, None)
         fi.update.assert_called_once_with(data)
         fi.create.assert_called_once_with(self.ctx)
 
+    @mock.patch('solum.api.handlers.language_pack_handler.'
+                'LanguagePackHandler._start_build')
+    def test_languagepack_create_limit_reached(self, mock_lp_build,
+                                               mock_img):
+
+        data = {'name': 'new app1',
+                'source_uri': 'git@github.com/foo/foo.git'}
+        cfg.CONF.set_override('max_languagepack_limit', '1',
+                              group='api')
+        mock_img.get_num_of_lps.return_value = 1
+
+        handler = language_pack_handler.LanguagePackHandler(self.ctx)
+
+        self.assertRaises(exc.ResourceLimitExceeded, handler.create,
+                          data, lp_metadata=None, lp_params=None)
+
     def test_lp_create_bad_git_url(self, mock_img):
 
         invalid_urls_list = list()
@@ -68,13 +90,17 @@ class TestLanguagePackHandler(base.BaseTestCase):
         invalid_urls_list.append('http')
         invalid_urls_list.append('git')
 
+        cfg.CONF.set_override('max_languagepack_limit', '10',
+                              group='api')
+        mock_img.get_num_of_lps.return_value = 1
+
         for invalid_url in invalid_urls_list:
-            data = {'name': 'new app',
+            data = {'name': 'new app2',
                     'source_uri': invalid_url}
             handler = language_pack_handler.LanguagePackHandler(self.ctx)
 
             self.assertRaises(exc.BadRequest, handler.create, data,
-                              lp_metadata=None)
+                              lp_metadata=None, lp_params=None)
 
     @mock.patch('solum.common.solum_swiftclient.SwiftClient.delete_object')
     @mock.patch('solum.api.handlers.userlog_handler.UserlogHandler')
@@ -83,6 +109,8 @@ class TestLanguagePackHandler(base.BaseTestCase):
     def test_languagepack_delete(self, mock_app, mock_planlist,
                                  mock_log_handler,
                                  mock_swift_delete, mock_img):
+
+        cfg.CONF.worker.image_storage = "swift"
         fi = fakes.FakeImage()
         mock_img.get_lp_by_name_or_uuid.return_value = fi
         mock_img.destroy.return_value = {}
@@ -127,6 +155,7 @@ class TestLanguagePackHandler(base.BaseTestCase):
                                                         mock_log_handler,
                                                         mock_swift_delete,
                                                         mock_img):
+        cfg.CONF.worker.image_storage = "swift"
         fi = fakes.FakeImage()
         mock_img.get_lp_by_name_or_uuid.return_value = fi
         mock_img.destroy.return_value = {}
